<?php

/**
 * Functions for handling everything about the forms
 */

/**
 * Renders the form
 * @param  int $id POST ID of our CPT mwp_form
 * @return void     
 */
function mwp_render_form( $id ) {
	$form = new MWP_Form( $id );
	$form->render();
}

/**
 * Returns the list ID that is assigned to the form
 * @param  number $form_id ID of the form
 * @return number          List ID
 */
function mwp_get_form_list_id( $form_id ) {
	return get_post_meta( $form_id, 'mwp_mailchimp_list_id', true );
}

/**
 * Add Form error
 * @param  numeric $form_id POST ID of the form
 * @param  string $message Message
 * @return void          
 */
function mwp_add_form_error( $form_id, $message ) {
	$mwp = mwp();
	$mwp->errors->add( 'form-' . $form_id, $message );
}

/**
 * Get Form errors
 * @param  numeric $form_id 
 * @return array          
 */
function mwp_get_form_errors( $form_id ) {
	$mwp = mwp();
	return $mwp->errors->get_error_messages( 'form-' . $form_id );
}

/**
 * Subscribe User on Form Submit
 * Redirecting on a successful subscribe
 *
 * @hooked init
 * @return void
 */
function mwp_subscribe_user_on_form_submit() {

	if( isset( $_POST['mwp_subscribe_form_submit'] ) && $_POST['mwp_subscribe_form_submit'] != '' ) {
		$name = '';
		$email = '';
		$form_id = '';
     
		if( isset( $_POST['mwp_name'] ) ) {
			$name = $_POST['mwp_name'];
		}

		if( isset( $_POST['mwp_email'] ) ) {
			$email = $_POST['mwp_email'];
		}

		if( isset( $_POST['mwp_subscribe_form_submit'] ) ) {
			$form_id = $_POST['mwp_subscribe_form_submit'];
		}
 
		$result = mwp_subscribe_user( $form_id, $name, $email );
 
		if( $result['success'] == 1 && isset( $result['redirect'] ) ) {

			 
			$redirect = $result['redirect'];
			if( filter_var($redirect, FILTER_VALIDATE_URL) !== false && strpos( $redirect, 'http' ) !== false ) {
				wp_redirect( $redirect, 301 );
				exit;
			}
			

		}
	
	} 
}

/**
 * Subscribes a user to the Form (List)
 * @param  numeric $form_id
 * @param  string $name    
 * @param  string $email   
 * @return array          Contains success, redirect url and error messages
 */
function mwp_subscribe_user( $form_id, $name, $email ) {

		// Setting the default $result array
 		$result = array( 'success' => 1, 'redirect' => '', 'errors' => 0 );
 	
		if( $name == '' ) {

			mwp_add_form_error( $form_id, __( 'Enter a name', 'mwp' ) );

		}

		if( $email == '' ) {

			mwp_add_form_error( $form_id, __( 'Enter an email', 'mwp' ) );

		} else {

			if ( !filter_var( $email, FILTER_VALIDATE_EMAIL ) === false ) {
				
				$list_id = mwp_get_form_list_id( $form_id );
				
				if( $list_id != '' ) {

					$subscribe = mwp_subscribe_user_to_list( $list_id, $name, $email );

					if( $subscribe == true ) {

						$result['redirect'] = get_post_meta( $form_id, 'mwp_mailchimp_list_redirect', true );
						 
					} else {

						mwp_add_form_error( $form_id, $subscribe['title'] );
						
					}

				} else {

					mwp_add_form_error( $form_id, __( 'We can\' subscribe you right now. Please contact the administrator.', 'socialnano' ) );
				
				}

			} else {
				
				mwp_add_form_error( $form_id, __( 'Enter a valid email', 'socialnano' ) );

			}
		}

		$form_errors = mwp_get_form_errors( $form_id );
		// If there are errors, it was not successful
		if( count( $form_errors ) > 0 ) {

			$result['success'] = 0;
			$result['errors']  = $form_errors;

		}

		return $result;

}


/**
 * Get forms from database
 * @return array Array of Form Post Types
 */
function mwp_get_all_forms() {

	$args = array(
		'post_type' => 'mwp_form',
		'post_status' => 'publish',
		'posts_per_page' => -1
		);

	return get_posts( $args );

}

/**
 * Subscribing the user on AJAX
 * Used with React
 * @return void
 */
function mwp_subscribe_user_on_ajax() {
	check_ajax_referer( 'mwp_nonce', '_wpnonce' );
	$name = '';
	$email = '';
	$form_id = 0;
	$list_id = 0;
 
	$result = array();

	if( isset( $_POST['mwp_name'] ) && $_POST['mwp_name'] != ''  ) {
		$name = $_POST['mwp_name'];
	}

	if( isset( $_POST['mwp_email'] ) && $_POST['mwp_email'] != ''  ) {
		$email = $_POST['mwp_email'];
	}

	if( isset( $_POST['mwp_form_id'] ) && $_POST['mwp_form_id'] != ''  ) {
		$form_id = $_POST['mwp_form_id'];
	}

	$result = mwp_subscribe_user( $form_id, $name, $email );

	echo json_encode( $result );
	wp_die();
}