<?php

/**
 * Plugin Name: MailChimp WordPress Plugin
 * Description: Create MailChimp forms in WordPress to collect emails
 * Version: 1.0
 * Author: Igor Benic
 * Author URI: https://ibenic.com
 *
 * Text Domain: mwp
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

define( 'MWP_PATH', plugin_dir_path( __FILE__ ) );
define( 'MWP_URL', plugin_dir_url( __FILE__ ) );

final class MWP {

	/**
	 * Static Variable
	 * @var mixed
	 */
	private static $instance;

    /**
     * Holder of errors
     * @var object
     */
    public $errors;

	public static function getInstance()
    {
        if (null === static::$instance) {
            static::$instance = new static();
        }
        
        return static::$instance;
    }

    /**
     * Includes that are essential for this plugin
     */
    public function includes(){

        /** Core **/

        require_once MWP_PATH . 'inc/settings.php';
        require_once MWP_PATH . 'inc/cpt-form.php';
        require_once MWP_PATH . 'inc/class-mwp-form.php';

        /** Functions **/
        require_once MWP_PATH . 'inc/functions-mailchimp.php';
        require_once MWP_PATH . 'inc/functions-form.php';

        /** Widgets **/
        require_once MWP_PATH . 'inc/class-mwp-widget.php';

        /** 3rd Party **/

        require_once MWP_PATH . 'inc/MailChimp/MailChimp.php';

        /**
         * Include this admin-only files when in admin
         */
        if( is_admin() ) {
            require_once MWP_PATH . 'inc/admin/metabox-form.php';
        }
        
    }

    /**
     * Various hooks where we hook our functions
     */
    public function hooks() {
        add_action( 'widgets_init', array( $this, 'register_widgets' ) );
        add_action( 'admin_menu', 'mwp_settings' );
        add_action( 'init', 'mwp_cpt_form', 0 );
        add_action( 'init', 'mwp_subscribe_user_on_form_submit' );
        add_action( 'wp_enqueue_scripts', array( $this, 'enqueue' ) );
        add_action( 'wp_ajax_mwp_subscribe_user', 'mwp_subscribe_user_on_ajax' );
        add_action( 'wp_ajax_nopriv_mwp_subscribe_user', 'mwp_subscribe_user_on_ajax' );
    }

    /**
     * Enqueueing the scripts needed for MWP
     * @return void 
     */
    public function enqueue() {
       
        wp_register_script( 'mwp-js', MWP_URL . '/assets/mwp.js', array('jquery'), '1', true );
        wp_localize_script( 'mwp-js', 
                            'mwp_object', 
                            array( 
                                'ajax_url' => admin_url( 'admin-ajax.php' ), 
                                'nonce' => wp_create_nonce( 'mwp_nonce' ),
                                'texts' => array(
                                    'subscribe' => __( 'Subscribe', 'mwp' ),
                                    'subscribing' => __( 'Subscribing...', 'mwp' ),
                                    'empty_name' => __( 'Name is Empty', 'mwp' ),
                                    'empty_email' => __( 'Email is Empty', 'mwp' )
                                )));
        wp_enqueue_script( 'mwp-js');
    }

    /**
     * Registering widgets
     * @return void
     */
    public function register_widgets() {
        register_widget( 'MWP_Widget' );
    }

    /**
     * Create objects, call functions to start various features
     */
    public function create() {

        // Create only in admin
        if( is_admin() ) {
            new MWP_Form_Metabox();
        }

        $this->errors = new WP_Error();

    }

    /**
     * Protected constructor to prevent creating a new instance of the
     * *Singleton* via the `new` operator from outside of this class.
     */
    protected function __construct()
    {
    }

    /**
     * Private clone method to prevent cloning of the instance of the
     * *Singleton* instance.
     *
     * @return void
     */
    private function __clone()
    {
    }

    /**
     * Private unserialize method to prevent unserializing of the *Singleton*
     * instance.
     *
     * @return void
     */
    private function __wakeup()
    {
    }
}

/**
 * Get the single instance of our plugin main object
 * @return object
 */
function mwp(){
	return MWP::getInstance();
}

// Start the plugin once everything has been loaded
add_action( 'plugins_loaded', 'mwp_run' );

/**
 * Start the plugin and call every method that has to run on start 
 */
function mwp_run(){
	$mwp = mwp();
	$mwp->includes(); 
    $mwp->hooks();
    $mwp->create();
}